@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 __author__ = "Mikhail Fedosov (tbs.micle@gmail.com)"
-__version__ = "0.1.2.6"
+__version__ = "0.1.3"
 
 # http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/
 # http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
@@ -14,19 +14,44 @@ from multiprocessing import Pool
 class colors:
 	""" Colored terminal text
 	"""
-
-	HEADER = "\033[95m"
-	OKBLUE = "\033[94m"
 	OKGREEN = "\033[92m"
-	WARNING = "\033[93m"
 	FAIL = "\033[91m"
 	BOLD = "\033[1m"
 	ENDC = "\033[0m"
 
-	def __init__(self):
-		pass
+	@classmethod
+	def disable(cls):
+		colors.OKGREEN = ""
+		colors.FAIL = ""
+		colors.BOLD = ""
+		colors.ENDC = ""
 
 
+class symbols:
+	""" Status symbols
+	"""
+	FAIL = u"✖ "
+	UPDATE = u"⤤ "
+	OK = u"✓ "
+
+	@classmethod
+	def disable(cls):
+		symbols.FAIL = ""
+		symbols.UPDATE = ""
+		symbols.OK = ""
+
+	@classmethod
+	def simplify(cls):
+		symbols.FAIL = "FAIL "
+		symbols.UPDATE = "UP "
+		symbols.OK = "OK "
+
+
+# disable colors and simplify status symbols for Windows console
+if sys.platform == "win32":
+	colors.disable()
+	symbols.simplify()
+
 def check_package(dist):
 	pypi = xmlrpclib.ServerProxy("http://pypi.python.org/pypi")
 	available = pypi.package_releases(dist.project_name)
@@ -35,19 +60,19 @@ def check_package(dist):
 		available = pypi.package_releases(dist.project_name.capitalize())
 
 	if not available:
-		msg = colors.FAIL + u"✖ not found at PyPI" + colors.ENDC
+		msg = colors.FAIL + u"{symbols.FAIL}not found at PyPI".format(symbols=symbols) + colors.ENDC
 	elif available[0] != dist.version:
-		msg = u"{colors.OKGREEN}⤤ {colors.BOLD}{version}{colors.ENDC}".format(colors=colors, version=available[0])
+		msg = u"{colors.OKGREEN}{symbols.UPDATE}{colors.BOLD}{version}{colors.ENDC}".format(colors=colors, symbols=symbols, version=available[0])
 	else:
 		if "-v" in sys.argv:
-			msg = u"✓ up to date".format(colors=colors)
+			msg = u"{symbols.OK}up to date".format(colors=colors, symbols=symbols)
 		else:
 			msg = ""
 	if msg:
 		print(u"{dist.project_name:26} {colors.BOLD}{dist.version:12}{colors.ENDC} {msg}".format(colors=colors, dist=dist, msg=msg))
 
 def main():
-	pypi_pool = Pool(42)
+	pypi_pool = Pool()
 	pypi_pool.map(check_package, pip.get_installed_distributions())
 
 if __name__ == "__main__":
